==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/CalculatedColumn.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "format", 
    "formula", 
    "outputType"})
@JsonInclude(Include.NON_NULL)
public class CalculatedColumn implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("format")
    protected String format;

    @JsonProperty("formula")
    protected String formula;

    @JsonProperty("outputType")
    protected String outputType;

    protected CalculatedColumn() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.calculatedColumn";
    }

    @Property(name="format")
    @JsonIgnore
    public Optional<String> getFormat() {
        return Optional.ofNullable(format);
    }

    public CalculatedColumn withFormat(String format) {
        CalculatedColumn _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.calculatedColumn");
        _x.format = format;
        return _x;
    }

    @Property(name="formula")
    @JsonIgnore
    public Optional<String> getFormula() {
        return Optional.ofNullable(formula);
    }

    public CalculatedColumn withFormula(String formula) {
        CalculatedColumn _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.calculatedColumn");
        _x.formula = formula;
        return _x;
    }

    @Property(name="outputType")
    @JsonIgnore
    public Optional<String> getOutputType() {
        return Optional.ofNullable(outputType);
    }

    public CalculatedColumn withOutputType(String outputType) {
        CalculatedColumn _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.calculatedColumn");
        _x.outputType = outputType;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String format;
        private String formula;
        private String outputType;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder format(String format) {
            this.format = format;
            this.changedFields = changedFields.add("format");
            return this;
        }

        public Builder formula(String formula) {
            this.formula = formula;
            this.changedFields = changedFields.add("formula");
            return this;
        }

        public Builder outputType(String outputType) {
            this.outputType = outputType;
            this.changedFields = changedFields.add("outputType");
            return this;
        }

        public CalculatedColumn build() {
            CalculatedColumn _x = new CalculatedColumn();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.calculatedColumn";
            _x.format = format;
            _x.formula = formula;
            _x.outputType = outputType;
            return _x;
        }
    }

    private CalculatedColumn _copy() {
        CalculatedColumn _x = new CalculatedColumn();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.format = format;
        _x.formula = formula;
        _x.outputType = outputType;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CalculatedColumn[");
        b.append("format=");
        b.append(this.format);
        b.append(", ");
        b.append("formula=");
        b.append(this.formula);
        b.append(", ");
        b.append("outputType=");
        b.append(this.outputType);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/CalculatedColumn.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "format", 
    "formula", 
    "outputType"})
@JsonInclude(Include.NON_NULL)
public class CalculatedColumn implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("format")
    protected String format;

    @JsonProperty("formula")
    protected String formula;

    @JsonProperty("outputType")
    protected String outputType;

    protected CalculatedColumn() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.calculatedColumn";
    }

    @Property(name="format")
    @JsonIgnore
    public Optional<String> getFormat() {
        return Optional.ofNullable(format);
    }

    public CalculatedColumn withFormat(String format) {
        CalculatedColumn _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.calculatedColumn");
        _x.format = format;
        return _x;
    }

    @Property(name="formula")
    @JsonIgnore
    public Optional<String> getFormula() {
        return Optional.ofNullable(formula);
    }

    public CalculatedColumn withFormula(String formula) {
        CalculatedColumn _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.calculatedColumn");
        _x.formula = formula;
        return _x;
    }

    @Property(name="outputType")
    @JsonIgnore
    public Optional<String> getOutputType() {
        return Optional.ofNullable(outputType);
    }

    public CalculatedColumn withOutputType(String outputType) {
        CalculatedColumn _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.calculatedColumn");
        _x.outputType = outputType;
        return _x;
    }

    public CalculatedColumn withUnmappedField(String name, Object value) {
        CalculatedColumn _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String format;
        private String formula;
        private String outputType;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder format(String format) {
            this.format = format;
            this.changedFields = changedFields.add("format");
            return this;
        }

        public Builder formula(String formula) {
            this.formula = formula;
            this.changedFields = changedFields.add("formula");
            return this;
        }

        public Builder outputType(String outputType) {
            this.outputType = outputType;
            this.changedFields = changedFields.add("outputType");
            return this;
        }

        public CalculatedColumn build() {
            CalculatedColumn _x = new CalculatedColumn();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.calculatedColumn";
            _x.format = format;
            _x.formula = formula;
            _x.outputType = outputType;
            return _x;
        }
    }

    private CalculatedColumn _copy() {
        CalculatedColumn _x = new CalculatedColumn();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.format = format;
        _x.formula = formula;
        _x.outputType = outputType;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CalculatedColumn[");
        b.append("format=");
        b.append(this.format);
        b.append(", ");
        b.append("formula=");
        b.append(this.formula);
        b.append(", ");
        b.append("outputType=");
        b.append(this.outputType);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
